@@ -8,8 +8,9 @@ use Sub::Exporter::ForMethods 'method_installer';
 use Data::Section { installer => method_installer }, '-setup';
 use namespace::autoclean;
 
-our $VERSION = '0.0501'; # VERSION
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
 # ABSTRACT: Check that all files in the projects end correctly
+our $VERSION = '0.0600';
 
 with 'Dist::Zilla::Role::FileGatherer',
      'Dist::Zilla::Role::TextTemplate',
@@ -95,9 +96,22 @@ __PACKAGE__->meta->make_immutable;
 
 Dist::Zilla::Plugin::Test::EOF - Check that all files in the projects end correctly
 
+
+
+=begin html
+
+<p>
+<img src="https://img.shields.io/badge/perl-5.10.1+-blue.svg" alt="Requires Perl 5.10.1+" />
+<a href="https://travis-ci.org/Csson/p5-dist-zilla-plugin-test-eof"><img src="https://api.travis-ci.org/Csson/p5-dist-zilla-plugin-test-eof.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/release/CSSON/Dist-Zilla-Plugin-Test-EOF-0.0600"><img src="http://badgedepot.code301.com/badge/kwalitee/CSSON/Dist-Zilla-Plugin-Test-EOF/0.0600" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Dist-Zilla-Plugin-Test-EOF%200.0600"><img src="http://badgedepot.code301.com/badge/cpantesters/Dist-Zilla-Plugin-Test-EOF/0.0600" alt="CPAN Testers result" /></a>
+</p>
+
+=end html
+
 =head1 VERSION
 
-Version 0.0501, released 2015-02-04.
+Version 0.0600, released 2018-07-31.
 
 =head1 SYNOPSIS
 
@@ -149,7 +163,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2018 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
